@@ -43,26 +43,52 @@ G_BEGIN_DECLS
      (g_base_info_get_type((GIBaseInfo*)info) == GI_INFO_TYPE_SIGNAL) || \
      (g_base_info_get_type((GIBaseInfo*)info) == GI_INFO_TYPE_VFUNC))
 
+
+GI_AVAILABLE_IN_1_34
 gboolean               g_callable_info_is_method (GICallableInfo *info);
+
+GI_AVAILABLE_IN_1_34
 gboolean               g_callable_info_can_throw_gerror (GICallableInfo *info);
+
+GI_AVAILABLE_IN_ALL
 GITypeInfo *           g_callable_info_get_return_type (GICallableInfo *info);
+
+GI_AVAILABLE_IN_ALL
 void                   g_callable_info_load_return_type (GICallableInfo *info,
                                                          GITypeInfo     *type);
+
+GI_AVAILABLE_IN_ALL
 const gchar *          g_callable_info_get_return_attribute (GICallableInfo *info,
                                                              const gchar    *name);
+
+GI_AVAILABLE_IN_ALL
 gboolean               g_callable_info_iterate_return_attributes (GICallableInfo  *info,
                                                                   GIAttributeIter *iterator,
                                                                   char           **name,
                                                                   char          **value);
+
+GI_AVAILABLE_IN_ALL
 GITransfer             g_callable_info_get_caller_owns (GICallableInfo *info);
+
+GI_AVAILABLE_IN_ALL
 gboolean               g_callable_info_may_return_null (GICallableInfo *info);
+
+GI_AVAILABLE_IN_ALL
 gboolean               g_callable_info_skip_return     (GICallableInfo *info);
+
+GI_AVAILABLE_IN_ALL
 gint                   g_callable_info_get_n_args      (GICallableInfo *info);
+
+GI_AVAILABLE_IN_ALL
 GIArgInfo *            g_callable_info_get_arg         (GICallableInfo *info,
                                                         gint            n);
+
+GI_AVAILABLE_IN_ALL
 void                   g_callable_info_load_arg        (GICallableInfo *info,
                                                         gint            n,
                                                         GIArgInfo      *arg);
+
+GI_AVAILABLE_IN_1_34
 gboolean               g_callable_info_invoke          (GICallableInfo   *info,
                                                         gpointer          function,
                                                         const GIArgument *in_args,
@@ -73,6 +99,8 @@ gboolean               g_callable_info_invoke          (GICallableInfo   *info,
                                                         gboolean          is_method,
                                                         gboolean          throws,
                                                         GError          **error);
+
+GI_AVAILABLE_IN_1_42
 GITransfer             g_callable_info_get_instance_ownership_transfer (GICallableInfo *info);
 
 G_END_DECLS
