@@ -26,7 +26,6 @@ import tempfile
 import sys
 import distutils
 
-from distutils.msvccompiler import MSVCCompiler
 from distutils.unixccompiler import UnixCCompiler
 from distutils.cygwinccompiler import Mingw32CCompiler
 from distutils.sysconfig import get_config_vars
@@ -35,6 +34,17 @@ from distutils.sysconfig import customize_compiler as orig_customize_compiler
 from . import utils
 
 
+def no_as_needed(linker):
+    """\
+    Filter out -Wl,--as-needed from the shell-quoted arguments in linker.
+    """
+    return ' '.join(
+        [shlex.quote(arg)
+         for arg in shlex.split(linker)
+         if arg != '-Wl,--as-needed']
+    )
+
+
 def customize_compiler(compiler):
     """This is a version of distutils.sysconfig.customize_compiler, without
     any macOS specific bits and which tries to avoid using any Python specific
@@ -88,13 +98,48 @@ def customize_compiler(compiler):
             compiler=cc_cmd,
             compiler_so=cc_cmd,
             compiler_cxx=cxx,
-            linker_so=ldshared,
-            linker_exe=cc,
+            linker_so=no_as_needed(ldshared),
+            linker_exe=no_as_needed(cc),
             archiver=archiver)
 
         compiler.shared_lib_extension = shlib_suffix
 
 
+def resolve_mingw_lib(implib, libtool=None):
+    """Returns a DLL name given a path to an import lib
+
+    /full/path/to/libgtk-3.dll.a -> libgtk-3-0.dll
+    """
+
+    args = []
+    if libtool:
+        args.extend(libtool)
+        args.append('--mode=execute')
+
+    # Figure out if we have a gcc toolchain or llvm one
+    dlltool = os.environ.get('DLLTOOL', 'dlltool.exe')
+    dlltool_output = subprocess.run(
+        [dlltool], stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+        universal_newlines=True).stdout
+    is_llvm = 'llvm-dlltool' in dlltool_output
+
+    if not is_llvm:
+        # gcc dlltool provides this via --identify
+        dlltool_args = args + [dlltool, '--identify']
+        output = subprocess.check_output(dlltool_args + [implib], universal_newlines=True)
+        for line in output.splitlines():
+            return line
+    else:
+        # for llvm we need to parse the output of nm
+        # https://github.com/msys2/MINGW-packages/issues/11994#issuecomment-1176691216
+        output = subprocess.check_output(args + ['nm', implib], universal_newlines=True)
+        for line in output.splitlines():
+            if line.endswith(':'):
+                return line[:-1]
+    return None
+
+
 # Flags that retain macros in preprocessed output.
 FLAGS_RETAINING_MACROS = ['-g3', '-ggdb3', '-gstabs3', '-gcoff3', '-gxcoff3', '-gvms3']
 
@@ -116,7 +161,8 @@ class CCompiler(object):
             # as the official Python binaries are built with
             # Visual Studio
             if compiler_name is None:
-                if environ.get('MSYSTEM') == 'MINGW32' or environ.get('MSYSTEM') == 'MINGW64':
+                mingw = environ.get('MSYSTEM', '')
+                if mingw.startswith(('MINGW', 'CLANG', 'UCRT')) and environ.get('VCINSTALLDIR') is None:
                     compiler_name = 'mingw32'
                 else:
                     compiler_name = distutils.ccompiler.get_default_compiler()
@@ -124,18 +170,18 @@ class CCompiler(object):
                compiler_name != 'mingw32':
                 raise SystemExit('Specified Compiler \'%s\' is unsupported.' % compiler_name)
         else:
-            # XXX: Is it common practice to use a non-Unix compiler
-            #      class instance on non-Windows on platforms g-i supports?
-            compiler_name = distutils.ccompiler.get_default_compiler()
+            if compiler_name is None:
+                # XXX: Is it common practice to use a non-Unix compiler
+                #      class instance on non-Windows on platforms g-i supports?
+                compiler_name = distutils.ccompiler.get_default_compiler()
 
         # Now, create the distutils ccompiler instance based on the info we have.
         if compiler_name == 'msvc':
             # For MSVC, we need to create a instance of a subclass of distutil's
-            # MSVC9Compiler class, as it does not provide a preprocess()
+            # MSVCCompiler class, as it does not provide a preprocess()
             # implementation
             from . import msvccompiler
             self.compiler = msvccompiler.get_msvc_compiler()
-
         else:
             self.compiler = distutils.ccompiler.new_compiler(compiler=compiler_name)
         customize_compiler(self.compiler)
@@ -163,9 +209,11 @@ class CCompiler(object):
                 elif os.environ.get('VCInstallDir'):
                     os.environ['MSSdk'] = os.environ.get('VCInstallDir')
 
-            self.compiler_cmd = 'cl.exe'
-
-            self._cflags_no_deprecation_warnings = "-wd4996"
+            if self.compiler.check_is_clang_cl():
+                self.compiler_cmd = os.environ.get('CC').split()[0]
+            else:
+                self.compiler_cmd = 'cl.exe'
+                self._cflags_no_deprecation_warnings = "-wd4996"
         else:
             if (isinstance(self.compiler, Mingw32CCompiler)):
                 self.compiler_cmd = self.compiler.compiler[0]
@@ -193,10 +241,10 @@ class CCompiler(object):
                 # https://bugzilla.gnome.org/show_bug.cgi?id=625195
                 args.append('-Wl,-rpath,.')
 
-                # Ensure libraries are always linked as we are going to use ldd to work
-                # out their names later
-                if sys.platform != 'darwin':
-                    args.append('-Wl,--no-as-needed')
+            # Ensure libraries are always linked as we are going to use ldd to work
+            # out their names later
+            if sys.platform != 'darwin':
+                args.append('-Wl,--no-as-needed')
 
         for library_path in libpaths:
             # The dumper program needs to look for dynamic libraries
@@ -206,7 +254,7 @@ class CCompiler(object):
                 args.append('-libpath:' + library_path)
             else:
                 args.append('-L' + library_path)
-                if os.path.isabs(library_path):
+                if os.name != 'nt' and os.path.isabs(library_path):
                     if libtool:
                         args.append('-rpath')
                         args.append(library_path)
@@ -216,13 +264,16 @@ class CCompiler(object):
             runtime_paths.append(library_path)
 
         for library in libraries + extra_libraries:
-            if self.check_is_msvc():
+            if os.path.isfile(library):
+                # If we get a real filename, just use it as-is
+                args.append(library)
+            elif self.check_is_msvc():
                 # Note that Visual Studio builds do not use libtool!
                 if library != 'm':
                     args.append(library + '.lib')
             else:
                 # If we get a real filename, just use it as-is
-                if library.endswith(".la") or os.path.isfile(library):
+                if library.endswith(".la"):
                     args.append(library)
                 else:
                     args.append('-l' + library)
@@ -239,11 +290,19 @@ class CCompiler(object):
         # is installed on the system; this case is used for the scanning
         # of GLib in gobject-introspection itself.
 
+        # Ensure libraries are always linked as we are going to use ldd to work
+        # out their names later
+        if os.name != 'nt' and sys.platform != 'darwin':
+            args.append('-Wl,--no-as-needed')
+
         for library in libraries:
-            if self.check_is_msvc():
-                # Visual Studio: don't attempt to link to m.lib
+            if os.path.isfile(library):
+                # If we get a real filename, just use it as-is
+                args.append(library)
+            elif self.check_is_msvc():
+                # Note that Visual Studio builds do not use libtool!
                 if library != 'm':
-                    args.append(library + ".lib")
+                    args.append(library + '.lib')
             else:
                 if library.endswith(".la"):  # explicitly specified libtool library
                     args.append(library)
@@ -263,7 +322,7 @@ class CCompiler(object):
         # Define these macros when using Visual C++ to silence many warnings,
         # and prevent stepping on many Visual Studio-specific items, so that
         # we don't have to handle them specifically in scannerlexer.l
-        if self.check_is_msvc():
+        if self.check_is_msvc() and not self.compiler.check_is_clang_cl():
             macros.append(('_USE_DECLSPECS_FOR_SAL', None))
             macros.append(('_CRT_SECURE_NO_WARNINGS', None))
             macros.append(('_CRT_NONSTDC_NO_WARNINGS', None))
@@ -318,7 +377,7 @@ class CCompiler(object):
         args = []
         libsearch = []
 
-        # When we are using Visual C++...
+        # When we are using Visual C++ or clang-cl...
         if self.check_is_msvc():
             # The search path of the .lib's on Visual C++
             # is dependent on the LIB environmental variable,
@@ -336,13 +395,9 @@ class CCompiler(object):
             args.append('dumpbin.exe')
             args.append('-symbols')
 
-        # When we are not using Visual C++ (i.e. we are using GCC)...
+        # When we are not using Visual C++ nor clang-cl (i.e. we are using GCC)...
         else:
             libtool = utils.get_libtool_command(options)
-            if libtool:
-                args.extend(libtool)
-                args.append('--mode=execute')
-            args.extend([os.environ.get('DLLTOOL', 'dlltool.exe'), '--identify'])
             proc = subprocess.Popen([self.compiler_cmd, '-print-search-dirs'],
                                     stdout=subprocess.PIPE)
             o, e = proc.communicate()
@@ -357,6 +412,7 @@ class CCompiler(object):
             found = False
             candidates = [
                 'lib%s.dll.a' % lib,
+                'lib%s.dll.lib' % lib,  # rust cdylib
                 'lib%s.a' % lib,
                 '%s.dll.a' % lib,
                 '%s.a' % lib,
@@ -385,7 +441,7 @@ class CCompiler(object):
                             output_flag = ['-out:' + tmp_filename]
                             proc = subprocess.call(args + [implib] + output_flag,
                                                    stdout=subprocess.PIPE)
-                            with open(tmp_filename, 'r') as tmp_fileobj:
+                            with open(tmp_filename, 'r', encoding='utf-8') as tmp_fileobj:
                                 for line in tmp_fileobj.read().splitlines():
 
                                     if '__IMPORT_DESCRIPTOR_' in line:
@@ -398,13 +454,10 @@ class CCompiler(object):
                             tmp_fileobj.close()
                             os.unlink(tmp_filename)
                         else:
-                            proc = subprocess.Popen(args + [implib],
-                                                    stdout=subprocess.PIPE)
-                            o, e = proc.communicate()
-                            for line in o.decode('ascii').splitlines():
-                                shlibs.append(line)
+                            shlib = resolve_mingw_lib(implib, libtool)
+                            if shlib is not None:
+                                shlibs.append(shlib)
                                 found = True
-                                break
             if not found:
                 not_resolved.append(lib)
         if len(not_resolved) > 0:
@@ -423,7 +476,7 @@ class CCompiler(object):
             return self.compiler.linker_exe
 
     def check_is_msvc(self):
-        return isinstance(self.compiler, MSVCCompiler)
+        return self.compiler.compiler_type == "msvc"
 
     # Private APIs
     def _set_cpp_options(self, options):
@@ -449,7 +502,7 @@ class CCompiler(object):
                     # macros for compiling using distutils
                     # get dropped for MSVC builds, so
                     # escape the escape character.
-                    if isinstance(self.compiler, MSVCCompiler):
+                    if self.check_is_msvc():
                         macro_value = macro_value.replace('\"', '\\\"')
                 macros.append((macro_name, macro_value))
             elif option.startswith('-U'):
