@@ -10,7 +10,7 @@ typedef struct {
   double y;
 } SPoint;
 
-_GI_TEST_EXTERN
+GI_TEST_EXTERN
 void s_hello (void);
 
 /* Like GSpawnError; not registered with GType */
@@ -21,7 +21,7 @@ typedef enum
   S_SPAWN_ERROR_CODE3 = 3
 } SSpawnError;
 
-_GI_TEST_EXTERN
+GI_TEST_EXTERN
 GQuark s_spawn_error_quark (void);
 
 /* Like GDBusError but not registered with GType */
@@ -32,7 +32,7 @@ typedef enum
   S_DBUS_ERROR_CODE3 = 3
 } SDBusError;
 
-_GI_TEST_EXTERN
+GI_TEST_EXTERN
 GQuark s_dbus_error_quark (void);
 
 #endif
